# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DataSourceArgs', 'DataSource']

@pulumi.input_type
class DataSourceArgs:
    def __init__(__self__, *,
                 connection_properties: pulumi.Input[builtins.str],
                 connection_properties_mode: pulumi.Input[builtins.str],
                 data_source_name: pulumi.Input[builtins.str],
                 project_id: pulumi.Input[builtins.int],
                 type: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a DataSource resource.
        :param pulumi.Input[builtins.str] connection_properties: Data source connection configuration information, including the connection address, access identity, and environment information. The data source environment EnvType information is a member property of this object, including DEV (Development Environment) and PROD (production environment). The value of EnvType is not case-sensitive.
        :param pulumi.Input[builtins.str] connection_properties_mode: The configuration mode of the data source. Different types of data sources have different configuration modes. For example, MySQL data sources support UrlMode and InstanceMode.
        :param pulumi.Input[builtins.str] data_source_name: The data source name. The name of a data source in a specific environment (development environment or production environment) is unique in a project.
        :param pulumi.Input[builtins.int] project_id: The ID of the project to which the data source belongs.
        :param pulumi.Input[builtins.str] type: The type of data source. For a list of data source types, see the values listed in the API documentation.
        :param pulumi.Input[builtins.str] description: Description of the data source
        """
        pulumi.set(__self__, "connection_properties", connection_properties)
        pulumi.set(__self__, "connection_properties_mode", connection_properties_mode)
        pulumi.set(__self__, "data_source_name", data_source_name)
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "type", type)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="connectionProperties")
    def connection_properties(self) -> pulumi.Input[builtins.str]:
        """
        Data source connection configuration information, including the connection address, access identity, and environment information. The data source environment EnvType information is a member property of this object, including DEV (Development Environment) and PROD (production environment). The value of EnvType is not case-sensitive.
        """
        return pulumi.get(self, "connection_properties")

    @connection_properties.setter
    def connection_properties(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "connection_properties", value)

    @property
    @pulumi.getter(name="connectionPropertiesMode")
    def connection_properties_mode(self) -> pulumi.Input[builtins.str]:
        """
        The configuration mode of the data source. Different types of data sources have different configuration modes. For example, MySQL data sources support UrlMode and InstanceMode.
        """
        return pulumi.get(self, "connection_properties_mode")

    @connection_properties_mode.setter
    def connection_properties_mode(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "connection_properties_mode", value)

    @property
    @pulumi.getter(name="dataSourceName")
    def data_source_name(self) -> pulumi.Input[builtins.str]:
        """
        The data source name. The name of a data source in a specific environment (development environment or production environment) is unique in a project.
        """
        return pulumi.get(self, "data_source_name")

    @data_source_name.setter
    def data_source_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "data_source_name", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[builtins.int]:
        """
        The ID of the project to which the data source belongs.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[builtins.str]:
        """
        The type of data source. For a list of data source types, see the values listed in the API documentation.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description of the data source
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _DataSourceState:
    def __init__(__self__, *,
                 connection_properties: Optional[pulumi.Input[builtins.str]] = None,
                 connection_properties_mode: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.int]] = None,
                 create_user: Optional[pulumi.Input[builtins.str]] = None,
                 data_source_id: Optional[pulumi.Input[builtins.int]] = None,
                 data_source_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 modify_time: Optional[pulumi.Input[builtins.int]] = None,
                 modify_user: Optional[pulumi.Input[builtins.str]] = None,
                 project_id: Optional[pulumi.Input[builtins.int]] = None,
                 qualified_name: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering DataSource resources.
        :param pulumi.Input[builtins.str] connection_properties: Data source connection configuration information, including the connection address, access identity, and environment information. The data source environment EnvType information is a member property of this object, including DEV (Development Environment) and PROD (production environment). The value of EnvType is not case-sensitive.
        :param pulumi.Input[builtins.str] connection_properties_mode: The configuration mode of the data source. Different types of data sources have different configuration modes. For example, MySQL data sources support UrlMode and InstanceMode.
        :param pulumi.Input[builtins.int] create_time: The creation time of the resource
        :param pulumi.Input[builtins.str] create_user: Creator of the data source
        :param pulumi.Input[builtins.int] data_source_id: The first ID of the resource
        :param pulumi.Input[builtins.str] data_source_name: The data source name. The name of a data source in a specific environment (development environment or production environment) is unique in a project.
        :param pulumi.Input[builtins.str] description: Description of the data source
        :param pulumi.Input[builtins.int] modify_time: Modification time
        :param pulumi.Input[builtins.str] modify_user: Modifier of the data source
        :param pulumi.Input[builtins.int] project_id: The ID of the project to which the data source belongs.
        :param pulumi.Input[builtins.str] qualified_name: Business Unique Key of Data Source
        :param pulumi.Input[builtins.str] type: The type of data source. For a list of data source types, see the values listed in the API documentation.
        """
        if connection_properties is not None:
            pulumi.set(__self__, "connection_properties", connection_properties)
        if connection_properties_mode is not None:
            pulumi.set(__self__, "connection_properties_mode", connection_properties_mode)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if create_user is not None:
            pulumi.set(__self__, "create_user", create_user)
        if data_source_id is not None:
            pulumi.set(__self__, "data_source_id", data_source_id)
        if data_source_name is not None:
            pulumi.set(__self__, "data_source_name", data_source_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if modify_time is not None:
            pulumi.set(__self__, "modify_time", modify_time)
        if modify_user is not None:
            pulumi.set(__self__, "modify_user", modify_user)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if qualified_name is not None:
            pulumi.set(__self__, "qualified_name", qualified_name)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="connectionProperties")
    def connection_properties(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Data source connection configuration information, including the connection address, access identity, and environment information. The data source environment EnvType information is a member property of this object, including DEV (Development Environment) and PROD (production environment). The value of EnvType is not case-sensitive.
        """
        return pulumi.get(self, "connection_properties")

    @connection_properties.setter
    def connection_properties(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "connection_properties", value)

    @property
    @pulumi.getter(name="connectionPropertiesMode")
    def connection_properties_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The configuration mode of the data source. Different types of data sources have different configuration modes. For example, MySQL data sources support UrlMode and InstanceMode.
        """
        return pulumi.get(self, "connection_properties_mode")

    @connection_properties_mode.setter
    def connection_properties_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "connection_properties_mode", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="createUser")
    def create_user(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Creator of the data source
        """
        return pulumi.get(self, "create_user")

    @create_user.setter
    def create_user(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_user", value)

    @property
    @pulumi.getter(name="dataSourceId")
    def data_source_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "data_source_id")

    @data_source_id.setter
    def data_source_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "data_source_id", value)

    @property
    @pulumi.getter(name="dataSourceName")
    def data_source_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The data source name. The name of a data source in a specific environment (development environment or production environment) is unique in a project.
        """
        return pulumi.get(self, "data_source_name")

    @data_source_name.setter
    def data_source_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "data_source_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description of the data source
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="modifyTime")
    def modify_time(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Modification time
        """
        return pulumi.get(self, "modify_time")

    @modify_time.setter
    def modify_time(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "modify_time", value)

    @property
    @pulumi.getter(name="modifyUser")
    def modify_user(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Modifier of the data source
        """
        return pulumi.get(self, "modify_user")

    @modify_user.setter
    def modify_user(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "modify_user", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The ID of the project to which the data source belongs.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="qualifiedName")
    def qualified_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Business Unique Key of Data Source
        """
        return pulumi.get(self, "qualified_name")

    @qualified_name.setter
    def qualified_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "qualified_name", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of data source. For a list of data source types, see the values listed in the API documentation.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("alicloud:dataworks/dataSource:DataSource")
class DataSource(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connection_properties: Optional[pulumi.Input[builtins.str]] = None,
                 connection_properties_mode: Optional[pulumi.Input[builtins.str]] = None,
                 data_source_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_id: Optional[pulumi.Input[builtins.int]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Data Works Data Source resource.

        For information about Data Works Data Source and how to use it, see [What is Data Source](https://www.alibabacloud.com/help/en/dataworks/developer-reference/api-dataworks-public-2024-05-18-createdatasource).

        > **NOTE:** Available since v1.237.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import json
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf_example"
        randint = random.index.Integer("randint",
            max=999,
            min=1)
        default = alicloud.resourcemanager.get_resource_groups()
        defaultkguw4_r = alicloud.dataworks.Project("defaultkguw4R",
            status="Available",
            description="tf_desc",
            project_name=f"{name}{randint['id']}",
            pai_task_enabled=False,
            display_name="tf_new_api_display",
            dev_role_disabled=True,
            dev_environment_enabled=False,
            resource_group_id=default.ids[0])
        default_data_source = alicloud.dataworks.DataSource("default",
            type="hive",
            data_source_name=name,
            connection_properties=json.dumps({
                "address": [{
                    "host": "127.0.0.1",
                    "port": "1234",
                }],
                "database": "hive_database",
                "metaType": "HiveMetastore",
                "metastoreUris": "thrift://123:123",
                "version": "2.3.9",
                "loginMode": "Anonymous",
                "securityProtocol": "authTypeNone",
                "envType": "Prod",
                "properties": {
                    "key1": "value1",
                },
            }),
            connection_properties_mode="UrlMode",
            project_id=defaultkguw4_r.id,
            description=name)
        ```

        ## Import

        Data Works Data Source can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dataworks/dataSource:DataSource example <project_id>:<data_source_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] connection_properties: Data source connection configuration information, including the connection address, access identity, and environment information. The data source environment EnvType information is a member property of this object, including DEV (Development Environment) and PROD (production environment). The value of EnvType is not case-sensitive.
        :param pulumi.Input[builtins.str] connection_properties_mode: The configuration mode of the data source. Different types of data sources have different configuration modes. For example, MySQL data sources support UrlMode and InstanceMode.
        :param pulumi.Input[builtins.str] data_source_name: The data source name. The name of a data source in a specific environment (development environment or production environment) is unique in a project.
        :param pulumi.Input[builtins.str] description: Description of the data source
        :param pulumi.Input[builtins.int] project_id: The ID of the project to which the data source belongs.
        :param pulumi.Input[builtins.str] type: The type of data source. For a list of data source types, see the values listed in the API documentation.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DataSourceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Data Works Data Source resource.

        For information about Data Works Data Source and how to use it, see [What is Data Source](https://www.alibabacloud.com/help/en/dataworks/developer-reference/api-dataworks-public-2024-05-18-createdatasource).

        > **NOTE:** Available since v1.237.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import json
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf_example"
        randint = random.index.Integer("randint",
            max=999,
            min=1)
        default = alicloud.resourcemanager.get_resource_groups()
        defaultkguw4_r = alicloud.dataworks.Project("defaultkguw4R",
            status="Available",
            description="tf_desc",
            project_name=f"{name}{randint['id']}",
            pai_task_enabled=False,
            display_name="tf_new_api_display",
            dev_role_disabled=True,
            dev_environment_enabled=False,
            resource_group_id=default.ids[0])
        default_data_source = alicloud.dataworks.DataSource("default",
            type="hive",
            data_source_name=name,
            connection_properties=json.dumps({
                "address": [{
                    "host": "127.0.0.1",
                    "port": "1234",
                }],
                "database": "hive_database",
                "metaType": "HiveMetastore",
                "metastoreUris": "thrift://123:123",
                "version": "2.3.9",
                "loginMode": "Anonymous",
                "securityProtocol": "authTypeNone",
                "envType": "Prod",
                "properties": {
                    "key1": "value1",
                },
            }),
            connection_properties_mode="UrlMode",
            project_id=defaultkguw4_r.id,
            description=name)
        ```

        ## Import

        Data Works Data Source can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dataworks/dataSource:DataSource example <project_id>:<data_source_id>
        ```

        :param str resource_name: The name of the resource.
        :param DataSourceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DataSourceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connection_properties: Optional[pulumi.Input[builtins.str]] = None,
                 connection_properties_mode: Optional[pulumi.Input[builtins.str]] = None,
                 data_source_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_id: Optional[pulumi.Input[builtins.int]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DataSourceArgs.__new__(DataSourceArgs)

            if connection_properties is None and not opts.urn:
                raise TypeError("Missing required property 'connection_properties'")
            __props__.__dict__["connection_properties"] = None if connection_properties is None else pulumi.Output.secret(connection_properties)
            if connection_properties_mode is None and not opts.urn:
                raise TypeError("Missing required property 'connection_properties_mode'")
            __props__.__dict__["connection_properties_mode"] = connection_properties_mode
            if data_source_name is None and not opts.urn:
                raise TypeError("Missing required property 'data_source_name'")
            __props__.__dict__["data_source_name"] = data_source_name
            __props__.__dict__["description"] = description
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["create_time"] = None
            __props__.__dict__["create_user"] = None
            __props__.__dict__["data_source_id"] = None
            __props__.__dict__["modify_time"] = None
            __props__.__dict__["modify_user"] = None
            __props__.__dict__["qualified_name"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["connectionProperties"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(DataSource, __self__).__init__(
            'alicloud:dataworks/dataSource:DataSource',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            connection_properties: Optional[pulumi.Input[builtins.str]] = None,
            connection_properties_mode: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.int]] = None,
            create_user: Optional[pulumi.Input[builtins.str]] = None,
            data_source_id: Optional[pulumi.Input[builtins.int]] = None,
            data_source_name: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            modify_time: Optional[pulumi.Input[builtins.int]] = None,
            modify_user: Optional[pulumi.Input[builtins.str]] = None,
            project_id: Optional[pulumi.Input[builtins.int]] = None,
            qualified_name: Optional[pulumi.Input[builtins.str]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None) -> 'DataSource':
        """
        Get an existing DataSource resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] connection_properties: Data source connection configuration information, including the connection address, access identity, and environment information. The data source environment EnvType information is a member property of this object, including DEV (Development Environment) and PROD (production environment). The value of EnvType is not case-sensitive.
        :param pulumi.Input[builtins.str] connection_properties_mode: The configuration mode of the data source. Different types of data sources have different configuration modes. For example, MySQL data sources support UrlMode and InstanceMode.
        :param pulumi.Input[builtins.int] create_time: The creation time of the resource
        :param pulumi.Input[builtins.str] create_user: Creator of the data source
        :param pulumi.Input[builtins.int] data_source_id: The first ID of the resource
        :param pulumi.Input[builtins.str] data_source_name: The data source name. The name of a data source in a specific environment (development environment or production environment) is unique in a project.
        :param pulumi.Input[builtins.str] description: Description of the data source
        :param pulumi.Input[builtins.int] modify_time: Modification time
        :param pulumi.Input[builtins.str] modify_user: Modifier of the data source
        :param pulumi.Input[builtins.int] project_id: The ID of the project to which the data source belongs.
        :param pulumi.Input[builtins.str] qualified_name: Business Unique Key of Data Source
        :param pulumi.Input[builtins.str] type: The type of data source. For a list of data source types, see the values listed in the API documentation.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DataSourceState.__new__(_DataSourceState)

        __props__.__dict__["connection_properties"] = connection_properties
        __props__.__dict__["connection_properties_mode"] = connection_properties_mode
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["create_user"] = create_user
        __props__.__dict__["data_source_id"] = data_source_id
        __props__.__dict__["data_source_name"] = data_source_name
        __props__.__dict__["description"] = description
        __props__.__dict__["modify_time"] = modify_time
        __props__.__dict__["modify_user"] = modify_user
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["qualified_name"] = qualified_name
        __props__.__dict__["type"] = type
        return DataSource(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="connectionProperties")
    def connection_properties(self) -> pulumi.Output[builtins.str]:
        """
        Data source connection configuration information, including the connection address, access identity, and environment information. The data source environment EnvType information is a member property of this object, including DEV (Development Environment) and PROD (production environment). The value of EnvType is not case-sensitive.
        """
        return pulumi.get(self, "connection_properties")

    @property
    @pulumi.getter(name="connectionPropertiesMode")
    def connection_properties_mode(self) -> pulumi.Output[builtins.str]:
        """
        The configuration mode of the data source. Different types of data sources have different configuration modes. For example, MySQL data sources support UrlMode and InstanceMode.
        """
        return pulumi.get(self, "connection_properties_mode")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.int]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="createUser")
    def create_user(self) -> pulumi.Output[builtins.str]:
        """
        Creator of the data source
        """
        return pulumi.get(self, "create_user")

    @property
    @pulumi.getter(name="dataSourceId")
    def data_source_id(self) -> pulumi.Output[builtins.int]:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "data_source_id")

    @property
    @pulumi.getter(name="dataSourceName")
    def data_source_name(self) -> pulumi.Output[builtins.str]:
        """
        The data source name. The name of a data source in a specific environment (development environment or production environment) is unique in a project.
        """
        return pulumi.get(self, "data_source_name")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Description of the data source
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="modifyTime")
    def modify_time(self) -> pulumi.Output[builtins.int]:
        """
        Modification time
        """
        return pulumi.get(self, "modify_time")

    @property
    @pulumi.getter(name="modifyUser")
    def modify_user(self) -> pulumi.Output[builtins.str]:
        """
        Modifier of the data source
        """
        return pulumi.get(self, "modify_user")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[builtins.int]:
        """
        The ID of the project to which the data source belongs.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="qualifiedName")
    def qualified_name(self) -> pulumi.Output[builtins.str]:
        """
        Business Unique Key of Data Source
        """
        return pulumi.get(self, "qualified_name")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        The type of data source. For a list of data source types, see the values listed in the API documentation.
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ServiceQueueDlqPolicyArgs',
    'ServiceQueueDlqPolicyArgsDict',
    'ServiceSubscriptionDlqPolicyArgs',
    'ServiceSubscriptionDlqPolicyArgsDict',
]

MYPY = False

if not MYPY:
    class ServiceQueueDlqPolicyArgsDict(TypedDict):
        dead_letter_target_queue: NotRequired[pulumi.Input[builtins.str]]
        """
        The queue to which dead-letter messages are delivered.
        """
        enabled: NotRequired[pulumi.Input[builtins.bool]]
        """
        Specifies whether to enable the dead-letter message delivery. Valid values: `true`, `false`.
        """
        max_receive_count: NotRequired[pulumi.Input[builtins.int]]
        """
        The maximum number of retries.
        """
elif False:
    ServiceQueueDlqPolicyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServiceQueueDlqPolicyArgs:
    def __init__(__self__, *,
                 dead_letter_target_queue: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 max_receive_count: Optional[pulumi.Input[builtins.int]] = None):
        """
        :param pulumi.Input[builtins.str] dead_letter_target_queue: The queue to which dead-letter messages are delivered.
        :param pulumi.Input[builtins.bool] enabled: Specifies whether to enable the dead-letter message delivery. Valid values: `true`, `false`.
        :param pulumi.Input[builtins.int] max_receive_count: The maximum number of retries.
        """
        if dead_letter_target_queue is not None:
            pulumi.set(__self__, "dead_letter_target_queue", dead_letter_target_queue)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if max_receive_count is not None:
            pulumi.set(__self__, "max_receive_count", max_receive_count)

    @property
    @pulumi.getter(name="deadLetterTargetQueue")
    def dead_letter_target_queue(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The queue to which dead-letter messages are delivered.
        """
        return pulumi.get(self, "dead_letter_target_queue")

    @dead_letter_target_queue.setter
    def dead_letter_target_queue(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dead_letter_target_queue", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether to enable the dead-letter message delivery. Valid values: `true`, `false`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="maxReceiveCount")
    def max_receive_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The maximum number of retries.
        """
        return pulumi.get(self, "max_receive_count")

    @max_receive_count.setter
    def max_receive_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_receive_count", value)


if not MYPY:
    class ServiceSubscriptionDlqPolicyArgsDict(TypedDict):
        dead_letter_target_queue: NotRequired[pulumi.Input[builtins.str]]
        """
        The queue to which dead-letter messages are delivered.
        """
        enabled: NotRequired[pulumi.Input[builtins.bool]]
        """
        Specifies whether to enable the dead-letter message delivery. Valid values: `true`, `false`.
        """
elif False:
    ServiceSubscriptionDlqPolicyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServiceSubscriptionDlqPolicyArgs:
    def __init__(__self__, *,
                 dead_letter_target_queue: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None):
        """
        :param pulumi.Input[builtins.str] dead_letter_target_queue: The queue to which dead-letter messages are delivered.
        :param pulumi.Input[builtins.bool] enabled: Specifies whether to enable the dead-letter message delivery. Valid values: `true`, `false`.
        """
        if dead_letter_target_queue is not None:
            pulumi.set(__self__, "dead_letter_target_queue", dead_letter_target_queue)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)

    @property
    @pulumi.getter(name="deadLetterTargetQueue")
    def dead_letter_target_queue(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The queue to which dead-letter messages are delivered.
        """
        return pulumi.get(self, "dead_letter_target_queue")

    @dead_letter_target_queue.setter
    def dead_letter_target_queue(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dead_letter_target_queue", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether to enable the dead-letter message delivery. Valid values: `true`, `false`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NodeGroupArgs', 'NodeGroup']

@pulumi.input_type
class NodeGroupArgs:
    def __init__(__self__, *,
                 az: pulumi.Input[builtins.str],
                 cluster_id: pulumi.Input[builtins.str],
                 image_id: pulumi.Input[builtins.str],
                 machine_type: pulumi.Input[builtins.str],
                 node_group_name: pulumi.Input[builtins.str],
                 ignore_failed_node_tasks: Optional[pulumi.Input[builtins.bool]] = None,
                 ip_allocation_policies: Optional[pulumi.Input[Sequence[pulumi.Input['NodeGroupIpAllocationPolicyArgs']]]] = None,
                 node_group_description: Optional[pulumi.Input[builtins.str]] = None,
                 nodes: Optional[pulumi.Input[Sequence[pulumi.Input['NodeGroupNodeArgs']]]] = None,
                 user_data: Optional[pulumi.Input[builtins.str]] = None,
                 vpd_subnets: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 vswitch_zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a NodeGroup resource.
        :param pulumi.Input[builtins.str] az: Az
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID
        :param pulumi.Input[builtins.str] image_id: Image ID
        :param pulumi.Input[builtins.str] machine_type: Machine type
        :param pulumi.Input[builtins.str] node_group_name: The name of the resource
        :param pulumi.Input[builtins.bool] ignore_failed_node_tasks: Whether to allow skipping failed nodes. Default value: False
        :param pulumi.Input[Sequence[pulumi.Input['NodeGroupIpAllocationPolicyArgs']]] ip_allocation_policies: IP address combination policy: only one policy type can be selected for each policy, and multiple policies can be combined. See `ip_allocation_policy` below.
        :param pulumi.Input[builtins.str] node_group_description: NodeGroupDescription
        :param pulumi.Input[Sequence[pulumi.Input['NodeGroupNodeArgs']]] nodes: Node List See `nodes` below.
        :param pulumi.Input[builtins.str] user_data: Custom Data
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] vpd_subnets: Cluster subnet list
        :param pulumi.Input[builtins.str] vswitch_zone_id: Zone ID of the switch
        :param pulumi.Input[builtins.str] zone_id: Zone ID
        """
        pulumi.set(__self__, "az", az)
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "image_id", image_id)
        pulumi.set(__self__, "machine_type", machine_type)
        pulumi.set(__self__, "node_group_name", node_group_name)
        if ignore_failed_node_tasks is not None:
            pulumi.set(__self__, "ignore_failed_node_tasks", ignore_failed_node_tasks)
        if ip_allocation_policies is not None:
            pulumi.set(__self__, "ip_allocation_policies", ip_allocation_policies)
        if node_group_description is not None:
            pulumi.set(__self__, "node_group_description", node_group_description)
        if nodes is not None:
            pulumi.set(__self__, "nodes", nodes)
        if user_data is not None:
            pulumi.set(__self__, "user_data", user_data)
        if vpd_subnets is not None:
            pulumi.set(__self__, "vpd_subnets", vpd_subnets)
        if vswitch_zone_id is not None:
            pulumi.set(__self__, "vswitch_zone_id", vswitch_zone_id)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter
    def az(self) -> pulumi.Input[builtins.str]:
        """
        Az
        """
        return pulumi.get(self, "az")

    @az.setter
    def az(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "az", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[builtins.str]:
        """
        Cluster ID
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> pulumi.Input[builtins.str]:
        """
        Image ID
        """
        return pulumi.get(self, "image_id")

    @image_id.setter
    def image_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "image_id", value)

    @property
    @pulumi.getter(name="machineType")
    def machine_type(self) -> pulumi.Input[builtins.str]:
        """
        Machine type
        """
        return pulumi.get(self, "machine_type")

    @machine_type.setter
    def machine_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "machine_type", value)

    @property
    @pulumi.getter(name="nodeGroupName")
    def node_group_name(self) -> pulumi.Input[builtins.str]:
        """
        The name of the resource
        """
        return pulumi.get(self, "node_group_name")

    @node_group_name.setter
    def node_group_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "node_group_name", value)

    @property
    @pulumi.getter(name="ignoreFailedNodeTasks")
    def ignore_failed_node_tasks(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to allow skipping failed nodes. Default value: False
        """
        return pulumi.get(self, "ignore_failed_node_tasks")

    @ignore_failed_node_tasks.setter
    def ignore_failed_node_tasks(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ignore_failed_node_tasks", value)

    @property
    @pulumi.getter(name="ipAllocationPolicies")
    def ip_allocation_policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NodeGroupIpAllocationPolicyArgs']]]]:
        """
        IP address combination policy: only one policy type can be selected for each policy, and multiple policies can be combined. See `ip_allocation_policy` below.
        """
        return pulumi.get(self, "ip_allocation_policies")

    @ip_allocation_policies.setter
    def ip_allocation_policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NodeGroupIpAllocationPolicyArgs']]]]):
        pulumi.set(self, "ip_allocation_policies", value)

    @property
    @pulumi.getter(name="nodeGroupDescription")
    def node_group_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NodeGroupDescription
        """
        return pulumi.get(self, "node_group_description")

    @node_group_description.setter
    def node_group_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "node_group_description", value)

    @property
    @pulumi.getter
    def nodes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NodeGroupNodeArgs']]]]:
        """
        Node List See `nodes` below.
        """
        return pulumi.get(self, "nodes")

    @nodes.setter
    def nodes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NodeGroupNodeArgs']]]]):
        pulumi.set(self, "nodes", value)

    @property
    @pulumi.getter(name="userData")
    def user_data(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Custom Data
        """
        return pulumi.get(self, "user_data")

    @user_data.setter
    def user_data(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_data", value)

    @property
    @pulumi.getter(name="vpdSubnets")
    def vpd_subnets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Cluster subnet list
        """
        return pulumi.get(self, "vpd_subnets")

    @vpd_subnets.setter
    def vpd_subnets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "vpd_subnets", value)

    @property
    @pulumi.getter(name="vswitchZoneId")
    def vswitch_zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Zone ID of the switch
        """
        return pulumi.get(self, "vswitch_zone_id")

    @vswitch_zone_id.setter
    def vswitch_zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vswitch_zone_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Zone ID
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.input_type
class _NodeGroupState:
    def __init__(__self__, *,
                 az: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 ignore_failed_node_tasks: Optional[pulumi.Input[builtins.bool]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 ip_allocation_policies: Optional[pulumi.Input[Sequence[pulumi.Input['NodeGroupIpAllocationPolicyArgs']]]] = None,
                 machine_type: Optional[pulumi.Input[builtins.str]] = None,
                 node_group_description: Optional[pulumi.Input[builtins.str]] = None,
                 node_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 node_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 nodes: Optional[pulumi.Input[Sequence[pulumi.Input['NodeGroupNodeArgs']]]] = None,
                 user_data: Optional[pulumi.Input[builtins.str]] = None,
                 vpd_subnets: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 vswitch_zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering NodeGroup resources.
        :param pulumi.Input[builtins.str] az: Az
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID
        :param pulumi.Input[builtins.str] create_time: Create time
        :param pulumi.Input[builtins.bool] ignore_failed_node_tasks: Whether to allow skipping failed nodes. Default value: False
        :param pulumi.Input[builtins.str] image_id: Image ID
        :param pulumi.Input[Sequence[pulumi.Input['NodeGroupIpAllocationPolicyArgs']]] ip_allocation_policies: IP address combination policy: only one policy type can be selected for each policy, and multiple policies can be combined. See `ip_allocation_policy` below.
        :param pulumi.Input[builtins.str] machine_type: Machine type
        :param pulumi.Input[builtins.str] node_group_description: NodeGroupDescription
        :param pulumi.Input[builtins.str] node_group_id: The first ID of the resource
        :param pulumi.Input[builtins.str] node_group_name: The name of the resource
        :param pulumi.Input[Sequence[pulumi.Input['NodeGroupNodeArgs']]] nodes: Node List See `nodes` below.
        :param pulumi.Input[builtins.str] user_data: Custom Data
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] vpd_subnets: Cluster subnet list
        :param pulumi.Input[builtins.str] vswitch_zone_id: Zone ID of the switch
        :param pulumi.Input[builtins.str] zone_id: Zone ID
        """
        if az is not None:
            pulumi.set(__self__, "az", az)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if ignore_failed_node_tasks is not None:
            pulumi.set(__self__, "ignore_failed_node_tasks", ignore_failed_node_tasks)
        if image_id is not None:
            pulumi.set(__self__, "image_id", image_id)
        if ip_allocation_policies is not None:
            pulumi.set(__self__, "ip_allocation_policies", ip_allocation_policies)
        if machine_type is not None:
            pulumi.set(__self__, "machine_type", machine_type)
        if node_group_description is not None:
            pulumi.set(__self__, "node_group_description", node_group_description)
        if node_group_id is not None:
            pulumi.set(__self__, "node_group_id", node_group_id)
        if node_group_name is not None:
            pulumi.set(__self__, "node_group_name", node_group_name)
        if nodes is not None:
            pulumi.set(__self__, "nodes", nodes)
        if user_data is not None:
            pulumi.set(__self__, "user_data", user_data)
        if vpd_subnets is not None:
            pulumi.set(__self__, "vpd_subnets", vpd_subnets)
        if vswitch_zone_id is not None:
            pulumi.set(__self__, "vswitch_zone_id", vswitch_zone_id)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter
    def az(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Az
        """
        return pulumi.get(self, "az")

    @az.setter
    def az(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "az", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cluster ID
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Create time
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="ignoreFailedNodeTasks")
    def ignore_failed_node_tasks(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to allow skipping failed nodes. Default value: False
        """
        return pulumi.get(self, "ignore_failed_node_tasks")

    @ignore_failed_node_tasks.setter
    def ignore_failed_node_tasks(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ignore_failed_node_tasks", value)

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Image ID
        """
        return pulumi.get(self, "image_id")

    @image_id.setter
    def image_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_id", value)

    @property
    @pulumi.getter(name="ipAllocationPolicies")
    def ip_allocation_policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NodeGroupIpAllocationPolicyArgs']]]]:
        """
        IP address combination policy: only one policy type can be selected for each policy, and multiple policies can be combined. See `ip_allocation_policy` below.
        """
        return pulumi.get(self, "ip_allocation_policies")

    @ip_allocation_policies.setter
    def ip_allocation_policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NodeGroupIpAllocationPolicyArgs']]]]):
        pulumi.set(self, "ip_allocation_policies", value)

    @property
    @pulumi.getter(name="machineType")
    def machine_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Machine type
        """
        return pulumi.get(self, "machine_type")

    @machine_type.setter
    def machine_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "machine_type", value)

    @property
    @pulumi.getter(name="nodeGroupDescription")
    def node_group_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NodeGroupDescription
        """
        return pulumi.get(self, "node_group_description")

    @node_group_description.setter
    def node_group_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "node_group_description", value)

    @property
    @pulumi.getter(name="nodeGroupId")
    def node_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "node_group_id")

    @node_group_id.setter
    def node_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "node_group_id", value)

    @property
    @pulumi.getter(name="nodeGroupName")
    def node_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the resource
        """
        return pulumi.get(self, "node_group_name")

    @node_group_name.setter
    def node_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "node_group_name", value)

    @property
    @pulumi.getter
    def nodes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NodeGroupNodeArgs']]]]:
        """
        Node List See `nodes` below.
        """
        return pulumi.get(self, "nodes")

    @nodes.setter
    def nodes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NodeGroupNodeArgs']]]]):
        pulumi.set(self, "nodes", value)

    @property
    @pulumi.getter(name="userData")
    def user_data(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Custom Data
        """
        return pulumi.get(self, "user_data")

    @user_data.setter
    def user_data(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_data", value)

    @property
    @pulumi.getter(name="vpdSubnets")
    def vpd_subnets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Cluster subnet list
        """
        return pulumi.get(self, "vpd_subnets")

    @vpd_subnets.setter
    def vpd_subnets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "vpd_subnets", value)

    @property
    @pulumi.getter(name="vswitchZoneId")
    def vswitch_zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Zone ID of the switch
        """
        return pulumi.get(self, "vswitch_zone_id")

    @vswitch_zone_id.setter
    def vswitch_zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vswitch_zone_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Zone ID
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.type_token("alicloud:eflo/nodeGroup:NodeGroup")
class NodeGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 az: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 ignore_failed_node_tasks: Optional[pulumi.Input[builtins.bool]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 ip_allocation_policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NodeGroupIpAllocationPolicyArgs', 'NodeGroupIpAllocationPolicyArgsDict']]]]] = None,
                 machine_type: Optional[pulumi.Input[builtins.str]] = None,
                 node_group_description: Optional[pulumi.Input[builtins.str]] = None,
                 node_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 nodes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NodeGroupNodeArgs', 'NodeGroupNodeArgsDict']]]]] = None,
                 user_data: Optional[pulumi.Input[builtins.str]] = None,
                 vpd_subnets: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 vswitch_zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Eflo Node Group resource.

        Node group. Divide a cluster into multiple node groups, each containing multiple nodes.

        For information about Eflo Node Group and how to use it, see [What is Node Group](https://next.api.alibabacloud.com/document/eflo-controller/2022-12-15/CreateNodeGroup).

        > **NOTE:** Available since v1.246.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.resourcemanager.get_resource_groups()
        create_vpc = alicloud.vpc.Network("create_vpc",
            cidr_block="192.168.0.0/16",
            vpc_name="cluster-resoure-example")
        create_vswitch = alicloud.vpc.Switch("create_vswitch",
            vpc_id=create_vpc.id,
            zone_id="cn-hangzhou-b",
            cidr_block="192.168.0.0/24",
            vswitch_name="cluster-resoure-example")
        create_security_group = alicloud.ecs.SecurityGroup("create_security_group",
            description="sg",
            security_group_name="cluster-resoure-example",
            security_group_type="normal",
            vpc_id=create_vpc.id)
        default_cluster = alicloud.eflo.Cluster("default",
            cluster_description="cluster-resource-example",
            open_eni_jumbo_frame=False,
            hpn_zone="B1",
            nimiz_vswitches=["1111"],
            ignore_failed_node_tasks=True,
            resource_group_id=default.ids[1],
            node_groups=[{
                "image_id": "i198448731735114628708",
                "zone_id": "cn-hangzhou-b",
                "node_group_name": "cluster-resource-example",
                "node_group_description": "cluster-resource-example",
                "machine_type": "efg2.C48cA3sen",
            }],
            networks={
                "tail_ip_version": "ipv4",
                "new_vpd_info": {
                    "monitor_vpc_id": create_vpc.id,
                    "monitor_vswitch_id": create_vswitch.id,
                    "cen_id": "11111",
                    "cloud_link_id": "1111",
                    "vpd_cidr": "111",
                    "vpd_subnets": [{
                        "zone_id": "1111",
                        "subnet_cidr": "111",
                        "subnet_type": "111",
                    }],
                    "cloud_link_cidr": "169.254.128.0/23",
                },
                "security_group_id": create_security_group.id,
                "vswitch_zone_id": "cn-hangzhou-b",
                "vpc_id": create_vpc.id,
                "vswitch_id": create_vswitch.id,
                "vpd_info": {
                    "vpd_id": "111",
                    "vpd_subnets": ["111"],
                },
                "ip_allocation_policies": [{
                    "bond_policy": {
                        "bond_default_subnet": "111",
                        "bonds": [{
                            "name": "111",
                            "subnet": "111",
                        }],
                    },
                    "machine_type_policies": [{
                        "bonds": [{
                            "name": "111",
                            "subnet": "111",
                        }],
                        "machine_type": "111",
                    }],
                    "node_policies": [{
                        "bonds": [{
                            "name": "111",
                            "subnet": "111",
                        }],
                        "node_id": "111",
                    }],
                }],
            },
            cluster_name="tfacceflo7165",
            cluster_type="Lite")
        default_node = alicloud.eflo.Node("default",
            period=36,
            discount_level="36",
            billing_cycle="1month",
            classify="gpuserver",
            zone="cn-hangzhou-b",
            product_form="instance",
            payment_ratio="0",
            hpn_zone="B1",
            server_arch="bmserver",
            computing_server="efg1.nvga1n",
            stage_num="36",
            renewal_status="AutoRenewal",
            renew_period=36,
            status="Unused")
        default_node_group = alicloud.eflo.NodeGroup("default",
            nodes=[{
                "node_id": default_node.id,
                "vpc_id": create_vpc.id,
                "vswitch_id": create_vswitch.id,
                "hostname": "jxyhostname",
                "login_password": "Alibaba@2025",
            }],
            ignore_failed_node_tasks=True,
            cluster_id=default_cluster.id,
            image_id="i195048661660874208657",
            zone_id="cn-hangzhou-b",
            vpd_subnets=["example"],
            user_data="YWxpLGFsaSxhbGliYWJh",
            vswitch_zone_id="cn-hangzhou-b",
            ip_allocation_policies=[{
                "bond_policy": {
                    "bond_default_subnet": "example",
                    "bonds": [{
                        "name": "example",
                        "subnet": "example",
                    }],
                },
                "machine_type_policies": [{
                    "bonds": [{
                        "name": "example",
                        "subnet": "example",
                    }],
                    "machine_type": "example",
                }],
                "node_policies": [{
                    "node_id": default_node.id,
                    "bonds": [{
                        "name": "example",
                        "subnet": "example",
                    }],
                }],
            }],
            machine_type="efg1.nvga1",
            az="cn-hangzhou-b",
            node_group_description="resource-example1",
            node_group_name="tfacceflo63657_update")
        ```

        ## Import

        Eflo Node Group can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:eflo/nodeGroup:NodeGroup example <cluster_id>:<node_group_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] az: Az
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID
        :param pulumi.Input[builtins.bool] ignore_failed_node_tasks: Whether to allow skipping failed nodes. Default value: False
        :param pulumi.Input[builtins.str] image_id: Image ID
        :param pulumi.Input[Sequence[pulumi.Input[Union['NodeGroupIpAllocationPolicyArgs', 'NodeGroupIpAllocationPolicyArgsDict']]]] ip_allocation_policies: IP address combination policy: only one policy type can be selected for each policy, and multiple policies can be combined. See `ip_allocation_policy` below.
        :param pulumi.Input[builtins.str] machine_type: Machine type
        :param pulumi.Input[builtins.str] node_group_description: NodeGroupDescription
        :param pulumi.Input[builtins.str] node_group_name: The name of the resource
        :param pulumi.Input[Sequence[pulumi.Input[Union['NodeGroupNodeArgs', 'NodeGroupNodeArgsDict']]]] nodes: Node List See `nodes` below.
        :param pulumi.Input[builtins.str] user_data: Custom Data
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] vpd_subnets: Cluster subnet list
        :param pulumi.Input[builtins.str] vswitch_zone_id: Zone ID of the switch
        :param pulumi.Input[builtins.str] zone_id: Zone ID
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NodeGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Eflo Node Group resource.

        Node group. Divide a cluster into multiple node groups, each containing multiple nodes.

        For information about Eflo Node Group and how to use it, see [What is Node Group](https://next.api.alibabacloud.com/document/eflo-controller/2022-12-15/CreateNodeGroup).

        > **NOTE:** Available since v1.246.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.resourcemanager.get_resource_groups()
        create_vpc = alicloud.vpc.Network("create_vpc",
            cidr_block="192.168.0.0/16",
            vpc_name="cluster-resoure-example")
        create_vswitch = alicloud.vpc.Switch("create_vswitch",
            vpc_id=create_vpc.id,
            zone_id="cn-hangzhou-b",
            cidr_block="192.168.0.0/24",
            vswitch_name="cluster-resoure-example")
        create_security_group = alicloud.ecs.SecurityGroup("create_security_group",
            description="sg",
            security_group_name="cluster-resoure-example",
            security_group_type="normal",
            vpc_id=create_vpc.id)
        default_cluster = alicloud.eflo.Cluster("default",
            cluster_description="cluster-resource-example",
            open_eni_jumbo_frame=False,
            hpn_zone="B1",
            nimiz_vswitches=["1111"],
            ignore_failed_node_tasks=True,
            resource_group_id=default.ids[1],
            node_groups=[{
                "image_id": "i198448731735114628708",
                "zone_id": "cn-hangzhou-b",
                "node_group_name": "cluster-resource-example",
                "node_group_description": "cluster-resource-example",
                "machine_type": "efg2.C48cA3sen",
            }],
            networks={
                "tail_ip_version": "ipv4",
                "new_vpd_info": {
                    "monitor_vpc_id": create_vpc.id,
                    "monitor_vswitch_id": create_vswitch.id,
                    "cen_id": "11111",
                    "cloud_link_id": "1111",
                    "vpd_cidr": "111",
                    "vpd_subnets": [{
                        "zone_id": "1111",
                        "subnet_cidr": "111",
                        "subnet_type": "111",
                    }],
                    "cloud_link_cidr": "169.254.128.0/23",
                },
                "security_group_id": create_security_group.id,
                "vswitch_zone_id": "cn-hangzhou-b",
                "vpc_id": create_vpc.id,
                "vswitch_id": create_vswitch.id,
                "vpd_info": {
                    "vpd_id": "111",
                    "vpd_subnets": ["111"],
                },
                "ip_allocation_policies": [{
                    "bond_policy": {
                        "bond_default_subnet": "111",
                        "bonds": [{
                            "name": "111",
                            "subnet": "111",
                        }],
                    },
                    "machine_type_policies": [{
                        "bonds": [{
                            "name": "111",
                            "subnet": "111",
                        }],
                        "machine_type": "111",
                    }],
                    "node_policies": [{
                        "bonds": [{
                            "name": "111",
                            "subnet": "111",
                        }],
                        "node_id": "111",
                    }],
                }],
            },
            cluster_name="tfacceflo7165",
            cluster_type="Lite")
        default_node = alicloud.eflo.Node("default",
            period=36,
            discount_level="36",
            billing_cycle="1month",
            classify="gpuserver",
            zone="cn-hangzhou-b",
            product_form="instance",
            payment_ratio="0",
            hpn_zone="B1",
            server_arch="bmserver",
            computing_server="efg1.nvga1n",
            stage_num="36",
            renewal_status="AutoRenewal",
            renew_period=36,
            status="Unused")
        default_node_group = alicloud.eflo.NodeGroup("default",
            nodes=[{
                "node_id": default_node.id,
                "vpc_id": create_vpc.id,
                "vswitch_id": create_vswitch.id,
                "hostname": "jxyhostname",
                "login_password": "Alibaba@2025",
            }],
            ignore_failed_node_tasks=True,
            cluster_id=default_cluster.id,
            image_id="i195048661660874208657",
            zone_id="cn-hangzhou-b",
            vpd_subnets=["example"],
            user_data="YWxpLGFsaSxhbGliYWJh",
            vswitch_zone_id="cn-hangzhou-b",
            ip_allocation_policies=[{
                "bond_policy": {
                    "bond_default_subnet": "example",
                    "bonds": [{
                        "name": "example",
                        "subnet": "example",
                    }],
                },
                "machine_type_policies": [{
                    "bonds": [{
                        "name": "example",
                        "subnet": "example",
                    }],
                    "machine_type": "example",
                }],
                "node_policies": [{
                    "node_id": default_node.id,
                    "bonds": [{
                        "name": "example",
                        "subnet": "example",
                    }],
                }],
            }],
            machine_type="efg1.nvga1",
            az="cn-hangzhou-b",
            node_group_description="resource-example1",
            node_group_name="tfacceflo63657_update")
        ```

        ## Import

        Eflo Node Group can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:eflo/nodeGroup:NodeGroup example <cluster_id>:<node_group_id>
        ```

        :param str resource_name: The name of the resource.
        :param NodeGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NodeGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 az: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 ignore_failed_node_tasks: Optional[pulumi.Input[builtins.bool]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 ip_allocation_policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NodeGroupIpAllocationPolicyArgs', 'NodeGroupIpAllocationPolicyArgsDict']]]]] = None,
                 machine_type: Optional[pulumi.Input[builtins.str]] = None,
                 node_group_description: Optional[pulumi.Input[builtins.str]] = None,
                 node_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 nodes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NodeGroupNodeArgs', 'NodeGroupNodeArgsDict']]]]] = None,
                 user_data: Optional[pulumi.Input[builtins.str]] = None,
                 vpd_subnets: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 vswitch_zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NodeGroupArgs.__new__(NodeGroupArgs)

            if az is None and not opts.urn:
                raise TypeError("Missing required property 'az'")
            __props__.__dict__["az"] = az
            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["ignore_failed_node_tasks"] = ignore_failed_node_tasks
            if image_id is None and not opts.urn:
                raise TypeError("Missing required property 'image_id'")
            __props__.__dict__["image_id"] = image_id
            __props__.__dict__["ip_allocation_policies"] = ip_allocation_policies
            if machine_type is None and not opts.urn:
                raise TypeError("Missing required property 'machine_type'")
            __props__.__dict__["machine_type"] = machine_type
            __props__.__dict__["node_group_description"] = node_group_description
            if node_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'node_group_name'")
            __props__.__dict__["node_group_name"] = node_group_name
            __props__.__dict__["nodes"] = nodes
            __props__.__dict__["user_data"] = user_data
            __props__.__dict__["vpd_subnets"] = vpd_subnets
            __props__.__dict__["vswitch_zone_id"] = vswitch_zone_id
            __props__.__dict__["zone_id"] = zone_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["node_group_id"] = None
        super(NodeGroup, __self__).__init__(
            'alicloud:eflo/nodeGroup:NodeGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            az: Optional[pulumi.Input[builtins.str]] = None,
            cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            ignore_failed_node_tasks: Optional[pulumi.Input[builtins.bool]] = None,
            image_id: Optional[pulumi.Input[builtins.str]] = None,
            ip_allocation_policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NodeGroupIpAllocationPolicyArgs', 'NodeGroupIpAllocationPolicyArgsDict']]]]] = None,
            machine_type: Optional[pulumi.Input[builtins.str]] = None,
            node_group_description: Optional[pulumi.Input[builtins.str]] = None,
            node_group_id: Optional[pulumi.Input[builtins.str]] = None,
            node_group_name: Optional[pulumi.Input[builtins.str]] = None,
            nodes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NodeGroupNodeArgs', 'NodeGroupNodeArgsDict']]]]] = None,
            user_data: Optional[pulumi.Input[builtins.str]] = None,
            vpd_subnets: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            vswitch_zone_id: Optional[pulumi.Input[builtins.str]] = None,
            zone_id: Optional[pulumi.Input[builtins.str]] = None) -> 'NodeGroup':
        """
        Get an existing NodeGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] az: Az
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID
        :param pulumi.Input[builtins.str] create_time: Create time
        :param pulumi.Input[builtins.bool] ignore_failed_node_tasks: Whether to allow skipping failed nodes. Default value: False
        :param pulumi.Input[builtins.str] image_id: Image ID
        :param pulumi.Input[Sequence[pulumi.Input[Union['NodeGroupIpAllocationPolicyArgs', 'NodeGroupIpAllocationPolicyArgsDict']]]] ip_allocation_policies: IP address combination policy: only one policy type can be selected for each policy, and multiple policies can be combined. See `ip_allocation_policy` below.
        :param pulumi.Input[builtins.str] machine_type: Machine type
        :param pulumi.Input[builtins.str] node_group_description: NodeGroupDescription
        :param pulumi.Input[builtins.str] node_group_id: The first ID of the resource
        :param pulumi.Input[builtins.str] node_group_name: The name of the resource
        :param pulumi.Input[Sequence[pulumi.Input[Union['NodeGroupNodeArgs', 'NodeGroupNodeArgsDict']]]] nodes: Node List See `nodes` below.
        :param pulumi.Input[builtins.str] user_data: Custom Data
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] vpd_subnets: Cluster subnet list
        :param pulumi.Input[builtins.str] vswitch_zone_id: Zone ID of the switch
        :param pulumi.Input[builtins.str] zone_id: Zone ID
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NodeGroupState.__new__(_NodeGroupState)

        __props__.__dict__["az"] = az
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["ignore_failed_node_tasks"] = ignore_failed_node_tasks
        __props__.__dict__["image_id"] = image_id
        __props__.__dict__["ip_allocation_policies"] = ip_allocation_policies
        __props__.__dict__["machine_type"] = machine_type
        __props__.__dict__["node_group_description"] = node_group_description
        __props__.__dict__["node_group_id"] = node_group_id
        __props__.__dict__["node_group_name"] = node_group_name
        __props__.__dict__["nodes"] = nodes
        __props__.__dict__["user_data"] = user_data
        __props__.__dict__["vpd_subnets"] = vpd_subnets
        __props__.__dict__["vswitch_zone_id"] = vswitch_zone_id
        __props__.__dict__["zone_id"] = zone_id
        return NodeGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def az(self) -> pulumi.Output[builtins.str]:
        """
        Az
        """
        return pulumi.get(self, "az")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[builtins.str]:
        """
        Cluster ID
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        Create time
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="ignoreFailedNodeTasks")
    def ignore_failed_node_tasks(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether to allow skipping failed nodes. Default value: False
        """
        return pulumi.get(self, "ignore_failed_node_tasks")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> pulumi.Output[builtins.str]:
        """
        Image ID
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="ipAllocationPolicies")
    def ip_allocation_policies(self) -> pulumi.Output[Optional[Sequence['outputs.NodeGroupIpAllocationPolicy']]]:
        """
        IP address combination policy: only one policy type can be selected for each policy, and multiple policies can be combined. See `ip_allocation_policy` below.
        """
        return pulumi.get(self, "ip_allocation_policies")

    @property
    @pulumi.getter(name="machineType")
    def machine_type(self) -> pulumi.Output[builtins.str]:
        """
        Machine type
        """
        return pulumi.get(self, "machine_type")

    @property
    @pulumi.getter(name="nodeGroupDescription")
    def node_group_description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        NodeGroupDescription
        """
        return pulumi.get(self, "node_group_description")

    @property
    @pulumi.getter(name="nodeGroupId")
    def node_group_id(self) -> pulumi.Output[builtins.str]:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "node_group_id")

    @property
    @pulumi.getter(name="nodeGroupName")
    def node_group_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the resource
        """
        return pulumi.get(self, "node_group_name")

    @property
    @pulumi.getter
    def nodes(self) -> pulumi.Output[Optional[Sequence['outputs.NodeGroupNode']]]:
        """
        Node List See `nodes` below.
        """
        return pulumi.get(self, "nodes")

    @property
    @pulumi.getter(name="userData")
    def user_data(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Custom Data
        """
        return pulumi.get(self, "user_data")

    @property
    @pulumi.getter(name="vpdSubnets")
    def vpd_subnets(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        Cluster subnet list
        """
        return pulumi.get(self, "vpd_subnets")

    @property
    @pulumi.getter(name="vswitchZoneId")
    def vswitch_zone_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Zone ID of the switch
        """
        return pulumi.get(self, "vswitch_zone_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Zone ID
        """
        return pulumi.get(self, "zone_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['OriginRuleArgs', 'OriginRule']

@pulumi.input_type
class OriginRuleArgs:
    def __init__(__self__, *,
                 site_id: pulumi.Input[builtins.int],
                 dns_record: Optional[pulumi.Input[builtins.str]] = None,
                 origin_host: Optional[pulumi.Input[builtins.str]] = None,
                 origin_http_port: Optional[pulumi.Input[builtins.str]] = None,
                 origin_https_port: Optional[pulumi.Input[builtins.str]] = None,
                 origin_scheme: Optional[pulumi.Input[builtins.str]] = None,
                 origin_sni: Optional[pulumi.Input[builtins.str]] = None,
                 range: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a OriginRule resource.
        :param pulumi.Input[builtins.int] site_id: The site ID.
        :param pulumi.Input[builtins.str] dns_record: Overwrite the DNS resolution record of the origin request.
        :param pulumi.Input[builtins.str] origin_host: The HOST carried in the back-to-origin request.
        :param pulumi.Input[builtins.str] origin_http_port: The port of the origin station accessed when the HTTP protocol is used to return to the origin.
        :param pulumi.Input[builtins.str] origin_https_port: The port of the origin station accessed when the HTTPS protocol is used to return to the origin.
        :param pulumi.Input[builtins.str] origin_scheme: The protocol used by the back-to-origin request. Value range:
        :param pulumi.Input[builtins.str] origin_sni: SNI carried in the back-to-origin request.
        :param pulumi.Input[builtins.str] range: Use the range sharding method to download the file from the source. Value range:
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               - Match all incoming requests: value set to true
               - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
               - on: open.
               - off: close.
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.int] site_version: The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        pulumi.set(__self__, "site_id", site_id)
        if dns_record is not None:
            pulumi.set(__self__, "dns_record", dns_record)
        if origin_host is not None:
            pulumi.set(__self__, "origin_host", origin_host)
        if origin_http_port is not None:
            pulumi.set(__self__, "origin_http_port", origin_http_port)
        if origin_https_port is not None:
            pulumi.set(__self__, "origin_https_port", origin_https_port)
        if origin_scheme is not None:
            pulumi.set(__self__, "origin_scheme", origin_scheme)
        if origin_sni is not None:
            pulumi.set(__self__, "origin_sni", origin_sni)
        if range is not None:
            pulumi.set(__self__, "range", range)
        if rule is not None:
            pulumi.set(__self__, "rule", rule)
        if rule_enable is not None:
            pulumi.set(__self__, "rule_enable", rule_enable)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if site_version is not None:
            pulumi.set(__self__, "site_version", site_version)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Input[builtins.int]:
        """
        The site ID.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="dnsRecord")
    def dns_record(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Overwrite the DNS resolution record of the origin request.
        """
        return pulumi.get(self, "dns_record")

    @dns_record.setter
    def dns_record(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dns_record", value)

    @property
    @pulumi.getter(name="originHost")
    def origin_host(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The HOST carried in the back-to-origin request.
        """
        return pulumi.get(self, "origin_host")

    @origin_host.setter
    def origin_host(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "origin_host", value)

    @property
    @pulumi.getter(name="originHttpPort")
    def origin_http_port(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The port of the origin station accessed when the HTTP protocol is used to return to the origin.
        """
        return pulumi.get(self, "origin_http_port")

    @origin_http_port.setter
    def origin_http_port(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "origin_http_port", value)

    @property
    @pulumi.getter(name="originHttpsPort")
    def origin_https_port(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The port of the origin station accessed when the HTTPS protocol is used to return to the origin.
        """
        return pulumi.get(self, "origin_https_port")

    @origin_https_port.setter
    def origin_https_port(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "origin_https_port", value)

    @property
    @pulumi.getter(name="originScheme")
    def origin_scheme(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The protocol used by the back-to-origin request. Value range:
        """
        return pulumi.get(self, "origin_scheme")

    @origin_scheme.setter
    def origin_scheme(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "origin_scheme", value)

    @property
    @pulumi.getter(name="originSni")
    def origin_sni(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SNI carried in the back-to-origin request.
        """
        return pulumi.get(self, "origin_sni")

    @origin_sni.setter
    def origin_sni(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "origin_sni", value)

    @property
    @pulumi.getter
    def range(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Use the range sharding method to download the file from the source. Value range:
        """
        return pulumi.get(self, "range")

    @range.setter
    def range(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "range", value)

    @property
    @pulumi.getter
    def rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        - Match all incoming requests: value set to true
        - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        - on: open.
        - off: close.
        """
        return pulumi.get(self, "rule_enable")

    @rule_enable.setter
    def rule_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_enable", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule name. When adding global configuration, this parameter does not need to be set.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        return pulumi.get(self, "site_version")

    @site_version.setter
    def site_version(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_version", value)


@pulumi.input_type
class _OriginRuleState:
    def __init__(__self__, *,
                 config_id: Optional[pulumi.Input[builtins.int]] = None,
                 dns_record: Optional[pulumi.Input[builtins.str]] = None,
                 origin_host: Optional[pulumi.Input[builtins.str]] = None,
                 origin_http_port: Optional[pulumi.Input[builtins.str]] = None,
                 origin_https_port: Optional[pulumi.Input[builtins.str]] = None,
                 origin_scheme: Optional[pulumi.Input[builtins.str]] = None,
                 origin_sni: Optional[pulumi.Input[builtins.str]] = None,
                 range: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering OriginRule resources.
        :param pulumi.Input[builtins.int] config_id: Back-to-source rule configuration ID
        :param pulumi.Input[builtins.str] dns_record: Overwrite the DNS resolution record of the origin request.
        :param pulumi.Input[builtins.str] origin_host: The HOST carried in the back-to-origin request.
        :param pulumi.Input[builtins.str] origin_http_port: The port of the origin station accessed when the HTTP protocol is used to return to the origin.
        :param pulumi.Input[builtins.str] origin_https_port: The port of the origin station accessed when the HTTPS protocol is used to return to the origin.
        :param pulumi.Input[builtins.str] origin_scheme: The protocol used by the back-to-origin request. Value range:
        :param pulumi.Input[builtins.str] origin_sni: SNI carried in the back-to-origin request.
        :param pulumi.Input[builtins.str] range: Use the range sharding method to download the file from the source. Value range:
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               - Match all incoming requests: value set to true
               - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
               - on: open.
               - off: close.
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.int] site_id: The site ID.
        :param pulumi.Input[builtins.int] site_version: The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        if config_id is not None:
            pulumi.set(__self__, "config_id", config_id)
        if dns_record is not None:
            pulumi.set(__self__, "dns_record", dns_record)
        if origin_host is not None:
            pulumi.set(__self__, "origin_host", origin_host)
        if origin_http_port is not None:
            pulumi.set(__self__, "origin_http_port", origin_http_port)
        if origin_https_port is not None:
            pulumi.set(__self__, "origin_https_port", origin_https_port)
        if origin_scheme is not None:
            pulumi.set(__self__, "origin_scheme", origin_scheme)
        if origin_sni is not None:
            pulumi.set(__self__, "origin_sni", origin_sni)
        if range is not None:
            pulumi.set(__self__, "range", range)
        if rule is not None:
            pulumi.set(__self__, "rule", rule)
        if rule_enable is not None:
            pulumi.set(__self__, "rule_enable", rule_enable)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if site_id is not None:
            pulumi.set(__self__, "site_id", site_id)
        if site_version is not None:
            pulumi.set(__self__, "site_version", site_version)

    @property
    @pulumi.getter(name="configId")
    def config_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Back-to-source rule configuration ID
        """
        return pulumi.get(self, "config_id")

    @config_id.setter
    def config_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "config_id", value)

    @property
    @pulumi.getter(name="dnsRecord")
    def dns_record(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Overwrite the DNS resolution record of the origin request.
        """
        return pulumi.get(self, "dns_record")

    @dns_record.setter
    def dns_record(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dns_record", value)

    @property
    @pulumi.getter(name="originHost")
    def origin_host(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The HOST carried in the back-to-origin request.
        """
        return pulumi.get(self, "origin_host")

    @origin_host.setter
    def origin_host(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "origin_host", value)

    @property
    @pulumi.getter(name="originHttpPort")
    def origin_http_port(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The port of the origin station accessed when the HTTP protocol is used to return to the origin.
        """
        return pulumi.get(self, "origin_http_port")

    @origin_http_port.setter
    def origin_http_port(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "origin_http_port", value)

    @property
    @pulumi.getter(name="originHttpsPort")
    def origin_https_port(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The port of the origin station accessed when the HTTPS protocol is used to return to the origin.
        """
        return pulumi.get(self, "origin_https_port")

    @origin_https_port.setter
    def origin_https_port(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "origin_https_port", value)

    @property
    @pulumi.getter(name="originScheme")
    def origin_scheme(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The protocol used by the back-to-origin request. Value range:
        """
        return pulumi.get(self, "origin_scheme")

    @origin_scheme.setter
    def origin_scheme(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "origin_scheme", value)

    @property
    @pulumi.getter(name="originSni")
    def origin_sni(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SNI carried in the back-to-origin request.
        """
        return pulumi.get(self, "origin_sni")

    @origin_sni.setter
    def origin_sni(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "origin_sni", value)

    @property
    @pulumi.getter
    def range(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Use the range sharding method to download the file from the source. Value range:
        """
        return pulumi.get(self, "range")

    @range.setter
    def range(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "range", value)

    @property
    @pulumi.getter
    def rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        - Match all incoming requests: value set to true
        - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        - on: open.
        - off: close.
        """
        return pulumi.get(self, "rule_enable")

    @rule_enable.setter
    def rule_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_enable", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule name. When adding global configuration, this parameter does not need to be set.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The site ID.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        return pulumi.get(self, "site_version")

    @site_version.setter
    def site_version(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_version", value)


@pulumi.type_token("alicloud:esa/originRule:OriginRule")
class OriginRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dns_record: Optional[pulumi.Input[builtins.str]] = None,
                 origin_host: Optional[pulumi.Input[builtins.str]] = None,
                 origin_http_port: Optional[pulumi.Input[builtins.str]] = None,
                 origin_https_port: Optional[pulumi.Input[builtins.str]] = None,
                 origin_scheme: Optional[pulumi.Input[builtins.str]] = None,
                 origin_sni: Optional[pulumi.Input[builtins.str]] = None,
                 range: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        Provides a ESA Origin Rule resource.

        For information about ESA Origin Rule and how to use it, see [What is Origin Rule](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateOriginRule).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        default_origin_rule = alicloud.esa.OriginRule("default",
            origin_sni="origin.example.com",
            site_id=default.sites[0].id,
            origin_host="origin.example.com",
            dns_record="tf.example.com",
            site_version=0,
            rule_name="tf",
            origin_https_port="443",
            origin_scheme="http",
            range="on",
            origin_http_port="8080",
            rule="(http.host eq \\"video.example.com\\")",
            rule_enable="on")
        ```

        ## Import

        ESA Origin Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/originRule:OriginRule example <site_id>:<config_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] dns_record: Overwrite the DNS resolution record of the origin request.
        :param pulumi.Input[builtins.str] origin_host: The HOST carried in the back-to-origin request.
        :param pulumi.Input[builtins.str] origin_http_port: The port of the origin station accessed when the HTTP protocol is used to return to the origin.
        :param pulumi.Input[builtins.str] origin_https_port: The port of the origin station accessed when the HTTPS protocol is used to return to the origin.
        :param pulumi.Input[builtins.str] origin_scheme: The protocol used by the back-to-origin request. Value range:
        :param pulumi.Input[builtins.str] origin_sni: SNI carried in the back-to-origin request.
        :param pulumi.Input[builtins.str] range: Use the range sharding method to download the file from the source. Value range:
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               - Match all incoming requests: value set to true
               - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
               - on: open.
               - off: close.
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.int] site_id: The site ID.
        :param pulumi.Input[builtins.int] site_version: The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OriginRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Origin Rule resource.

        For information about ESA Origin Rule and how to use it, see [What is Origin Rule](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateOriginRule).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        default_origin_rule = alicloud.esa.OriginRule("default",
            origin_sni="origin.example.com",
            site_id=default.sites[0].id,
            origin_host="origin.example.com",
            dns_record="tf.example.com",
            site_version=0,
            rule_name="tf",
            origin_https_port="443",
            origin_scheme="http",
            range="on",
            origin_http_port="8080",
            rule="(http.host eq \\"video.example.com\\")",
            rule_enable="on")
        ```

        ## Import

        ESA Origin Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/originRule:OriginRule example <site_id>:<config_id>
        ```

        :param str resource_name: The name of the resource.
        :param OriginRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OriginRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dns_record: Optional[pulumi.Input[builtins.str]] = None,
                 origin_host: Optional[pulumi.Input[builtins.str]] = None,
                 origin_http_port: Optional[pulumi.Input[builtins.str]] = None,
                 origin_https_port: Optional[pulumi.Input[builtins.str]] = None,
                 origin_scheme: Optional[pulumi.Input[builtins.str]] = None,
                 origin_sni: Optional[pulumi.Input[builtins.str]] = None,
                 range: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OriginRuleArgs.__new__(OriginRuleArgs)

            __props__.__dict__["dns_record"] = dns_record
            __props__.__dict__["origin_host"] = origin_host
            __props__.__dict__["origin_http_port"] = origin_http_port
            __props__.__dict__["origin_https_port"] = origin_https_port
            __props__.__dict__["origin_scheme"] = origin_scheme
            __props__.__dict__["origin_sni"] = origin_sni
            __props__.__dict__["range"] = range
            __props__.__dict__["rule"] = rule
            __props__.__dict__["rule_enable"] = rule_enable
            __props__.__dict__["rule_name"] = rule_name
            if site_id is None and not opts.urn:
                raise TypeError("Missing required property 'site_id'")
            __props__.__dict__["site_id"] = site_id
            __props__.__dict__["site_version"] = site_version
            __props__.__dict__["config_id"] = None
        super(OriginRule, __self__).__init__(
            'alicloud:esa/originRule:OriginRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            config_id: Optional[pulumi.Input[builtins.int]] = None,
            dns_record: Optional[pulumi.Input[builtins.str]] = None,
            origin_host: Optional[pulumi.Input[builtins.str]] = None,
            origin_http_port: Optional[pulumi.Input[builtins.str]] = None,
            origin_https_port: Optional[pulumi.Input[builtins.str]] = None,
            origin_scheme: Optional[pulumi.Input[builtins.str]] = None,
            origin_sni: Optional[pulumi.Input[builtins.str]] = None,
            range: Optional[pulumi.Input[builtins.str]] = None,
            rule: Optional[pulumi.Input[builtins.str]] = None,
            rule_enable: Optional[pulumi.Input[builtins.str]] = None,
            rule_name: Optional[pulumi.Input[builtins.str]] = None,
            site_id: Optional[pulumi.Input[builtins.int]] = None,
            site_version: Optional[pulumi.Input[builtins.int]] = None) -> 'OriginRule':
        """
        Get an existing OriginRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] config_id: Back-to-source rule configuration ID
        :param pulumi.Input[builtins.str] dns_record: Overwrite the DNS resolution record of the origin request.
        :param pulumi.Input[builtins.str] origin_host: The HOST carried in the back-to-origin request.
        :param pulumi.Input[builtins.str] origin_http_port: The port of the origin station accessed when the HTTP protocol is used to return to the origin.
        :param pulumi.Input[builtins.str] origin_https_port: The port of the origin station accessed when the HTTPS protocol is used to return to the origin.
        :param pulumi.Input[builtins.str] origin_scheme: The protocol used by the back-to-origin request. Value range:
        :param pulumi.Input[builtins.str] origin_sni: SNI carried in the back-to-origin request.
        :param pulumi.Input[builtins.str] range: Use the range sharding method to download the file from the source. Value range:
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               - Match all incoming requests: value set to true
               - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
               - on: open.
               - off: close.
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.int] site_id: The site ID.
        :param pulumi.Input[builtins.int] site_version: The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OriginRuleState.__new__(_OriginRuleState)

        __props__.__dict__["config_id"] = config_id
        __props__.__dict__["dns_record"] = dns_record
        __props__.__dict__["origin_host"] = origin_host
        __props__.__dict__["origin_http_port"] = origin_http_port
        __props__.__dict__["origin_https_port"] = origin_https_port
        __props__.__dict__["origin_scheme"] = origin_scheme
        __props__.__dict__["origin_sni"] = origin_sni
        __props__.__dict__["range"] = range
        __props__.__dict__["rule"] = rule
        __props__.__dict__["rule_enable"] = rule_enable
        __props__.__dict__["rule_name"] = rule_name
        __props__.__dict__["site_id"] = site_id
        __props__.__dict__["site_version"] = site_version
        return OriginRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="configId")
    def config_id(self) -> pulumi.Output[builtins.int]:
        """
        Back-to-source rule configuration ID
        """
        return pulumi.get(self, "config_id")

    @property
    @pulumi.getter(name="dnsRecord")
    def dns_record(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Overwrite the DNS resolution record of the origin request.
        """
        return pulumi.get(self, "dns_record")

    @property
    @pulumi.getter(name="originHost")
    def origin_host(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The HOST carried in the back-to-origin request.
        """
        return pulumi.get(self, "origin_host")

    @property
    @pulumi.getter(name="originHttpPort")
    def origin_http_port(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The port of the origin station accessed when the HTTP protocol is used to return to the origin.
        """
        return pulumi.get(self, "origin_http_port")

    @property
    @pulumi.getter(name="originHttpsPort")
    def origin_https_port(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The port of the origin station accessed when the HTTPS protocol is used to return to the origin.
        """
        return pulumi.get(self, "origin_https_port")

    @property
    @pulumi.getter(name="originScheme")
    def origin_scheme(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The protocol used by the back-to-origin request. Value range:
        """
        return pulumi.get(self, "origin_scheme")

    @property
    @pulumi.getter(name="originSni")
    def origin_sni(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        SNI carried in the back-to-origin request.
        """
        return pulumi.get(self, "origin_sni")

    @property
    @pulumi.getter
    def range(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Use the range sharding method to download the file from the source. Value range:
        """
        return pulumi.get(self, "range")

    @property
    @pulumi.getter
    def rule(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        - Match all incoming requests: value set to true
        - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        """
        return pulumi.get(self, "rule")

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        - on: open.
        - off: close.
        """
        return pulumi.get(self, "rule_enable")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule name. When adding global configuration, this parameter does not need to be set.
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Output[builtins.int]:
        """
        The site ID.
        """
        return pulumi.get(self, "site_id")

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        return pulumi.get(self, "site_version")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ClickHouseEnterpriseDbClusterArgs', 'ClickHouseEnterpriseDbCluster']

@pulumi.input_type
class ClickHouseEnterpriseDbClusterArgs:
    def __init__(__self__, *,
                 multi_zones: Optional[pulumi.Input[Sequence[pulumi.Input['ClickHouseEnterpriseDbClusterMultiZoneArgs']]]] = None,
                 scale_max: Optional[pulumi.Input[builtins.str]] = None,
                 scale_min: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vswitch_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a ClickHouseEnterpriseDbCluster resource.
        :param pulumi.Input[Sequence[pulumi.Input['ClickHouseEnterpriseDbClusterMultiZoneArgs']]] multi_zones: The list of multi-zone information. See `multi_zones` below.
        :param pulumi.Input[builtins.str] scale_max: The maximum value of serverless auto scaling.
        :param pulumi.Input[builtins.str] scale_min: The minimum value of serverless auto scaling.
        :param pulumi.Input[builtins.str] vpc_id: The VPC ID.
        :param pulumi.Input[builtins.str] vswitch_id: The vSwitch ID.
        :param pulumi.Input[builtins.str] zone_id: The zone ID.
        """
        if multi_zones is not None:
            pulumi.set(__self__, "multi_zones", multi_zones)
        if scale_max is not None:
            pulumi.set(__self__, "scale_max", scale_max)
        if scale_min is not None:
            pulumi.set(__self__, "scale_min", scale_min)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="multiZones")
    def multi_zones(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClickHouseEnterpriseDbClusterMultiZoneArgs']]]]:
        """
        The list of multi-zone information. See `multi_zones` below.
        """
        return pulumi.get(self, "multi_zones")

    @multi_zones.setter
    def multi_zones(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClickHouseEnterpriseDbClusterMultiZoneArgs']]]]):
        pulumi.set(self, "multi_zones", value)

    @property
    @pulumi.getter(name="scaleMax")
    def scale_max(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The maximum value of serverless auto scaling.
        """
        return pulumi.get(self, "scale_max")

    @scale_max.setter
    def scale_max(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scale_max", value)

    @property
    @pulumi.getter(name="scaleMin")
    def scale_min(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The minimum value of serverless auto scaling.
        """
        return pulumi.get(self, "scale_min")

    @scale_min.setter
    def scale_min(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scale_min", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The VPC ID.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The vSwitch ID.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vswitch_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The zone ID.
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.input_type
class _ClickHouseEnterpriseDbClusterState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 multi_zones: Optional[pulumi.Input[Sequence[pulumi.Input['ClickHouseEnterpriseDbClusterMultiZoneArgs']]]] = None,
                 region_id: Optional[pulumi.Input[builtins.str]] = None,
                 scale_max: Optional[pulumi.Input[builtins.str]] = None,
                 scale_min: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vswitch_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ClickHouseEnterpriseDbCluster resources.
        :param pulumi.Input[builtins.str] create_time: The creation time of the resource
        :param pulumi.Input[Sequence[pulumi.Input['ClickHouseEnterpriseDbClusterMultiZoneArgs']]] multi_zones: The list of multi-zone information. See `multi_zones` below.
        :param pulumi.Input[builtins.str] region_id: The region ID of the resource
        :param pulumi.Input[builtins.str] scale_max: The maximum value of serverless auto scaling.
        :param pulumi.Input[builtins.str] scale_min: The minimum value of serverless auto scaling.
        :param pulumi.Input[builtins.str] status: The status of the resource
        :param pulumi.Input[builtins.str] vpc_id: The VPC ID.
        :param pulumi.Input[builtins.str] vswitch_id: The vSwitch ID.
        :param pulumi.Input[builtins.str] zone_id: The zone ID.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if multi_zones is not None:
            pulumi.set(__self__, "multi_zones", multi_zones)
        if region_id is not None:
            pulumi.set(__self__, "region_id", region_id)
        if scale_max is not None:
            pulumi.set(__self__, "scale_max", scale_max)
        if scale_min is not None:
            pulumi.set(__self__, "scale_min", scale_min)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="multiZones")
    def multi_zones(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClickHouseEnterpriseDbClusterMultiZoneArgs']]]]:
        """
        The list of multi-zone information. See `multi_zones` below.
        """
        return pulumi.get(self, "multi_zones")

    @multi_zones.setter
    def multi_zones(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClickHouseEnterpriseDbClusterMultiZoneArgs']]]]):
        pulumi.set(self, "multi_zones", value)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The region ID of the resource
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter(name="scaleMax")
    def scale_max(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The maximum value of serverless auto scaling.
        """
        return pulumi.get(self, "scale_max")

    @scale_max.setter
    def scale_max(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scale_max", value)

    @property
    @pulumi.getter(name="scaleMin")
    def scale_min(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The minimum value of serverless auto scaling.
        """
        return pulumi.get(self, "scale_min")

    @scale_min.setter
    def scale_min(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scale_min", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The VPC ID.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The vSwitch ID.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vswitch_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The zone ID.
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.type_token("alicloud:clickhouseenterprisedbcluster/clickHouseEnterpriseDbCluster:ClickHouseEnterpriseDbCluster")
class ClickHouseEnterpriseDbCluster(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 multi_zones: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ClickHouseEnterpriseDbClusterMultiZoneArgs', 'ClickHouseEnterpriseDbClusterMultiZoneArgsDict']]]]] = None,
                 scale_max: Optional[pulumi.Input[builtins.str]] = None,
                 scale_min: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vswitch_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Click House Enterprise D B Cluster resource.

        Enterprise Edition Cluster Resources.

        For information about Click House Enterprise D B Cluster and how to use it, see [What is Enterprise D B Cluster](https://next.api.alibabacloud.com/document/clickhouse/2023-05-22/CreateDBInstance).

        > **NOTE:** Available since v1.247.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        vsw_ip_range_i = config.get("vswIpRangeI")
        if vsw_ip_range_i is None:
            vsw_ip_range_i = "172.16.1.0/24"
        region_id = config.get("regionId")
        if region_id is None:
            region_id = "cn-beijing"
        vpc_ip_range = config.get("vpcIpRange")
        if vpc_ip_range is None:
            vpc_ip_range = "172.16.0.0/12"
        vsw_ip_range_k = config.get("vswIpRangeK")
        if vsw_ip_range_k is None:
            vsw_ip_range_k = "172.16.3.0/24"
        vsw_ip_range_l = config.get("vswIpRangeL")
        if vsw_ip_range_l is None:
            vsw_ip_range_l = "172.16.2.0/24"
        zone_id_i = config.get("zoneIdI")
        if zone_id_i is None:
            zone_id_i = "cn-beijing-i"
        zone_id_l = config.get("zoneIdL")
        if zone_id_l is None:
            zone_id_l = "cn-beijing-l"
        zone_id_k = config.get("zoneIdK")
        if zone_id_k is None:
            zone_id_k = "cn-beijing-k"
        defaultkt_k_lu_m = alicloud.vpc.Network("defaultktKLuM", cidr_block=vpc_ip_range)
        default_tqwn3k = alicloud.vpc.Switch("defaultTQWN3k",
            vpc_id=defaultkt_k_lu_m.id,
            zone_id=zone_id_i,
            cidr_block=vsw_ip_range_i)
        defaultyly_lu8 = alicloud.vpc.Switch("defaultylyLu8",
            vpc_id=defaultkt_k_lu_m.id,
            zone_id=zone_id_l,
            cidr_block=vsw_ip_range_l)
        default_r_nb_ph8 = alicloud.vpc.Switch("defaultRNbPh8",
            vpc_id=defaultkt_k_lu_m.id,
            zone_id=zone_id_k,
            cidr_block=vsw_ip_range_k)
        default = alicloud.clickhouseenterprisedbcluster.ClickHouseEnterpriseDbCluster("default",
            zone_id=zone_id_i,
            vpc_id=defaultkt_k_lu_m.id,
            scale_min="8",
            scale_max="16",
            vswitch_id=default_tqwn3k.id,
            multi_zones=[
                {
                    "vswitch_ids": [default_tqwn3k.id],
                    "zone_id": zone_id_i,
                },
                {
                    "vswitch_ids": [defaultyly_lu8.id],
                    "zone_id": zone_id_l,
                },
                {
                    "vswitch_ids": [default_r_nb_ph8.id],
                    "zone_id": zone_id_k,
                },
            ])
        ```

        ## Import

        Click House Enterprise D B Cluster can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:clickhouseenterprisedbcluster/clickHouseEnterpriseDbCluster:ClickHouseEnterpriseDbCluster example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ClickHouseEnterpriseDbClusterMultiZoneArgs', 'ClickHouseEnterpriseDbClusterMultiZoneArgsDict']]]] multi_zones: The list of multi-zone information. See `multi_zones` below.
        :param pulumi.Input[builtins.str] scale_max: The maximum value of serverless auto scaling.
        :param pulumi.Input[builtins.str] scale_min: The minimum value of serverless auto scaling.
        :param pulumi.Input[builtins.str] vpc_id: The VPC ID.
        :param pulumi.Input[builtins.str] vswitch_id: The vSwitch ID.
        :param pulumi.Input[builtins.str] zone_id: The zone ID.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ClickHouseEnterpriseDbClusterArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Click House Enterprise D B Cluster resource.

        Enterprise Edition Cluster Resources.

        For information about Click House Enterprise D B Cluster and how to use it, see [What is Enterprise D B Cluster](https://next.api.alibabacloud.com/document/clickhouse/2023-05-22/CreateDBInstance).

        > **NOTE:** Available since v1.247.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        vsw_ip_range_i = config.get("vswIpRangeI")
        if vsw_ip_range_i is None:
            vsw_ip_range_i = "172.16.1.0/24"
        region_id = config.get("regionId")
        if region_id is None:
            region_id = "cn-beijing"
        vpc_ip_range = config.get("vpcIpRange")
        if vpc_ip_range is None:
            vpc_ip_range = "172.16.0.0/12"
        vsw_ip_range_k = config.get("vswIpRangeK")
        if vsw_ip_range_k is None:
            vsw_ip_range_k = "172.16.3.0/24"
        vsw_ip_range_l = config.get("vswIpRangeL")
        if vsw_ip_range_l is None:
            vsw_ip_range_l = "172.16.2.0/24"
        zone_id_i = config.get("zoneIdI")
        if zone_id_i is None:
            zone_id_i = "cn-beijing-i"
        zone_id_l = config.get("zoneIdL")
        if zone_id_l is None:
            zone_id_l = "cn-beijing-l"
        zone_id_k = config.get("zoneIdK")
        if zone_id_k is None:
            zone_id_k = "cn-beijing-k"
        defaultkt_k_lu_m = alicloud.vpc.Network("defaultktKLuM", cidr_block=vpc_ip_range)
        default_tqwn3k = alicloud.vpc.Switch("defaultTQWN3k",
            vpc_id=defaultkt_k_lu_m.id,
            zone_id=zone_id_i,
            cidr_block=vsw_ip_range_i)
        defaultyly_lu8 = alicloud.vpc.Switch("defaultylyLu8",
            vpc_id=defaultkt_k_lu_m.id,
            zone_id=zone_id_l,
            cidr_block=vsw_ip_range_l)
        default_r_nb_ph8 = alicloud.vpc.Switch("defaultRNbPh8",
            vpc_id=defaultkt_k_lu_m.id,
            zone_id=zone_id_k,
            cidr_block=vsw_ip_range_k)
        default = alicloud.clickhouseenterprisedbcluster.ClickHouseEnterpriseDbCluster("default",
            zone_id=zone_id_i,
            vpc_id=defaultkt_k_lu_m.id,
            scale_min="8",
            scale_max="16",
            vswitch_id=default_tqwn3k.id,
            multi_zones=[
                {
                    "vswitch_ids": [default_tqwn3k.id],
                    "zone_id": zone_id_i,
                },
                {
                    "vswitch_ids": [defaultyly_lu8.id],
                    "zone_id": zone_id_l,
                },
                {
                    "vswitch_ids": [default_r_nb_ph8.id],
                    "zone_id": zone_id_k,
                },
            ])
        ```

        ## Import

        Click House Enterprise D B Cluster can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:clickhouseenterprisedbcluster/clickHouseEnterpriseDbCluster:ClickHouseEnterpriseDbCluster example <id>
        ```

        :param str resource_name: The name of the resource.
        :param ClickHouseEnterpriseDbClusterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClickHouseEnterpriseDbClusterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 multi_zones: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ClickHouseEnterpriseDbClusterMultiZoneArgs', 'ClickHouseEnterpriseDbClusterMultiZoneArgsDict']]]]] = None,
                 scale_max: Optional[pulumi.Input[builtins.str]] = None,
                 scale_min: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vswitch_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClickHouseEnterpriseDbClusterArgs.__new__(ClickHouseEnterpriseDbClusterArgs)

            __props__.__dict__["multi_zones"] = multi_zones
            __props__.__dict__["scale_max"] = scale_max
            __props__.__dict__["scale_min"] = scale_min
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["vswitch_id"] = vswitch_id
            __props__.__dict__["zone_id"] = zone_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["region_id"] = None
            __props__.__dict__["status"] = None
        super(ClickHouseEnterpriseDbCluster, __self__).__init__(
            'alicloud:clickhouseenterprisedbcluster/clickHouseEnterpriseDbCluster:ClickHouseEnterpriseDbCluster',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            multi_zones: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ClickHouseEnterpriseDbClusterMultiZoneArgs', 'ClickHouseEnterpriseDbClusterMultiZoneArgsDict']]]]] = None,
            region_id: Optional[pulumi.Input[builtins.str]] = None,
            scale_max: Optional[pulumi.Input[builtins.str]] = None,
            scale_min: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            vswitch_id: Optional[pulumi.Input[builtins.str]] = None,
            zone_id: Optional[pulumi.Input[builtins.str]] = None) -> 'ClickHouseEnterpriseDbCluster':
        """
        Get an existing ClickHouseEnterpriseDbCluster resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] create_time: The creation time of the resource
        :param pulumi.Input[Sequence[pulumi.Input[Union['ClickHouseEnterpriseDbClusterMultiZoneArgs', 'ClickHouseEnterpriseDbClusterMultiZoneArgsDict']]]] multi_zones: The list of multi-zone information. See `multi_zones` below.
        :param pulumi.Input[builtins.str] region_id: The region ID of the resource
        :param pulumi.Input[builtins.str] scale_max: The maximum value of serverless auto scaling.
        :param pulumi.Input[builtins.str] scale_min: The minimum value of serverless auto scaling.
        :param pulumi.Input[builtins.str] status: The status of the resource
        :param pulumi.Input[builtins.str] vpc_id: The VPC ID.
        :param pulumi.Input[builtins.str] vswitch_id: The vSwitch ID.
        :param pulumi.Input[builtins.str] zone_id: The zone ID.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClickHouseEnterpriseDbClusterState.__new__(_ClickHouseEnterpriseDbClusterState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["multi_zones"] = multi_zones
        __props__.__dict__["region_id"] = region_id
        __props__.__dict__["scale_max"] = scale_max
        __props__.__dict__["scale_min"] = scale_min
        __props__.__dict__["status"] = status
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vswitch_id"] = vswitch_id
        __props__.__dict__["zone_id"] = zone_id
        return ClickHouseEnterpriseDbCluster(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="multiZones")
    def multi_zones(self) -> pulumi.Output[Sequence['outputs.ClickHouseEnterpriseDbClusterMultiZone']]:
        """
        The list of multi-zone information. See `multi_zones` below.
        """
        return pulumi.get(self, "multi_zones")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Output[builtins.str]:
        """
        The region ID of the resource
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter(name="scaleMax")
    def scale_max(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The maximum value of serverless auto scaling.
        """
        return pulumi.get(self, "scale_max")

    @property
    @pulumi.getter(name="scaleMin")
    def scale_min(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The minimum value of serverless auto scaling.
        """
        return pulumi.get(self, "scale_min")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The VPC ID.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The vSwitch ID.
        """
        return pulumi.get(self, "vswitch_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The zone ID.
        """
        return pulumi.get(self, "zone_id")

